.. _tutorials-taskqueue:

==================================
A Task Queue with a JSON-RPC Api
==================================

The code for this example is located in the :mod:`examples.taskqueue.manage`
module.

.. automodule:: examples.taskqueue.manage
